==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/show_docker_login_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDockerLoginResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'login_cmd': 'str'
    }

    attribute_map = {
        'login_cmd': 'login_cmd'
    }

    def __init__(self, login_cmd=None):
        """ShowDockerLoginResponse

        The model defined in huaweicloud sdk

        :param login_cmd: 临时登录指令
        :type login_cmd: str
        """
        
        super(ShowDockerLoginResponse, self).__init__()

        self._login_cmd = None
        self.discriminator = None

        if login_cmd is not None:
            self.login_cmd = login_cmd

    @property
    def login_cmd(self):
        """Gets the login_cmd of this ShowDockerLoginResponse.

        临时登录指令

        :return: The login_cmd of this ShowDockerLoginResponse.
        :rtype: str
        """
        return self._login_cmd

    @login_cmd.setter
    def login_cmd(self, login_cmd):
        """Sets the login_cmd of this ShowDockerLoginResponse.

        临时登录指令

        :param login_cmd: The login_cmd of this ShowDockerLoginResponse.
        :type login_cmd: str
        """
        self._login_cmd = login_cmd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDockerLoginResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.147-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/show_docker_login_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDockerLoginResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'login_cmd': 'str'
    }

    attribute_map = {
        'login_cmd': 'login_cmd'
    }

    def __init__(self, login_cmd=None):
        r"""ShowDockerLoginResponse

        The model defined in huaweicloud sdk

        :param login_cmd: 临时登录指令
        :type login_cmd: str
        """
        
        super(ShowDockerLoginResponse, self).__init__()

        self._login_cmd = None
        self.discriminator = None

        if login_cmd is not None:
            self.login_cmd = login_cmd

    @property
    def login_cmd(self):
        r"""Gets the login_cmd of this ShowDockerLoginResponse.

        临时登录指令

        :return: The login_cmd of this ShowDockerLoginResponse.
        :rtype: str
        """
        return self._login_cmd

    @login_cmd.setter
    def login_cmd(self, login_cmd):
        r"""Sets the login_cmd of this ShowDockerLoginResponse.

        临时登录指令

        :param login_cmd: The login_cmd of this ShowDockerLoginResponse.
        :type login_cmd: str
        """
        self._login_cmd = login_cmd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDockerLoginResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
